<?php

declare(strict_types=1);

namespace Apexl\Tests\Core\Infrastructure;

use apexl\Io\factories\EntityFactory;

/**
 * @method TestRelatedEntity create(array $attrs = [], bool $store = true)
 */
final readonly class TestRelatedEntityFactory extends EntityFactory
{

}