<?php

declare(strict_types=1);

namespace apexl\Io\interfaces;

interface GlobalDataInterface
{
    public function addData(string $key, mixed $data, bool $merge = true, bool $getData = false): void;

    public function getData(?string $key = null, bool $reload = false): mixed;

    public function replaceData(array $data): void;

}